@@ -66,17 +66,11 @@ esp_dict_region_code <- function(sourcevar,
   validvars <- c("text", "nuts", "iso2", "codauto", "cpro")
 
   if (!(origin %in% validvars)) {
-    stop(
-      "origin should be ",
-      paste0("'", validvars, "'", collapse = ", ")
-    )
+    stop("origin should be ", paste0("'", validvars, "'", collapse = ", "))
   }
 
   if (!(destination %in% validvars)) {
-    stop(
-      "destination should be ",
-      paste0("'", validvars, "'", collapse = ", ")
-    )
+    stop("destination should be ", paste0("'", validvars, "'", collapse = ", "))
   }
 
   if (origin == destination && origin == "text") {
@@ -87,17 +81,14 @@ esp_dict_region_code <- function(sourcevar,
   # Create dict
   dict <- names_full
 
-  names_dict <-
-    unique(names_full[
-      grep("name", dict$variable),
-      c("key", "value")
-    ])
+  names_dict <- unique(
+    names_full[grep("name", dict$variable), c("key", "value")]
+  )
 
   # If text convert to nuts
 
   if (origin == "text") {
-    sourcevar <- countrycode::countrycode(
-      tolower(sourcevar),
+    sourcevar <- countrycode::countrycode(tolower(sourcevar),
       origin = "value",
       destination = "key",
       custom_dict = names_dict,
@@ -105,8 +96,7 @@ esp_dict_region_code <- function(sourcevar,
     )
 
     # Translate to nuts
-    sourcevar <- countrycode::countrycode(
-      sourcevar,
+    sourcevar <- countrycode::countrycode(sourcevar,
       origin = "key",
       destination = "nuts",
       custom_dict = names2nuts,
@@ -114,8 +104,7 @@ esp_dict_region_code <- function(sourcevar,
     )
 
     # Replace NOMATCH
-    sourcevar[sourcevar == "NOMATCH"] <-
-      initsourcevar[sourcevar == "NOMATCH"]
+    sourcevar[sourcevar == "NOMATCH"] <- initsourcevar[sourcevar == "NOMATCH"]
     origin <- "nuts"
 
     # By name, perform some replacements
@@ -139,27 +128,19 @@ esp_dict_region_code <- function(sourcevar,
     }
   }
 
-
-
   # Destination
   if (destination == "text") {
-    sourcevar <-
-      countrycode::countrycode(sourcevar,
-        origin,
-        "nuts",
-        custom_dict = code2code,
-        nomatch = "NOMATCH"
-      )
+    sourcevar <- countrycode::countrycode(sourcevar, origin, "nuts",
+      custom_dict = code2code,
+      nomatch = "NOMATCH"
+    )
 
     dict_nutsall <- sf::st_drop_geometry(mapSpain::esp_nuts.sf)
 
-    out <-
-      countrycode::countrycode(sourcevar,
-        "NUTS_ID",
-        "NUTS_NAME",
-        custom_dict = dict_nutsall,
-        nomatch = "NOMATCH"
-      )
+    out <- countrycode::countrycode(sourcevar, "NUTS_ID", "NUTS_NAME",
+      custom_dict = dict_nutsall,
+      nomatch = "NOMATCH"
+    )
   } else {
     # Solve problems
     if (origin == "nuts") {
@@ -178,15 +159,9 @@ esp_dict_region_code <- function(sourcevar,
       sourcevar[sourcevar == "ES630"] <- "ES63"
     }
 
-
-
-    out <-
-      countrycode::countrycode(sourcevar,
-        origin,
-        destination,
-        custom_dict = code2code,
-        nomatch = "NOMATCH"
-      )
+    out <- countrycode::countrycode(sourcevar, origin, destination,
+      custom_dict = code2code, nomatch = "NOMATCH"
+    )
 
     # Baleares
     if (destination == "cpro") {
@@ -203,15 +178,12 @@ esp_dict_region_code <- function(sourcevar,
   # Sanitize
   if (length(out[!(out == "NOMATCH")]) != length(sourcevar)) {
     warning(
-      "No match on ",
-      destination,
-      " found for ",
+      "No match on ", destination, " found for ",
       paste0(initsourcevar[out == "NOMATCH"], collapse = ", ")
     )
   }
   out[out == "NOMATCH"] <- NA
 
-
   return(out)
 }
 
@@ -239,10 +211,8 @@ esp_dict_region_code <- function(sourcevar,
 #'
 #' @examples
 #'
-#' vals <- c(
-#'   "La Rioja", "Sevilla", "Madrid",
-#'   "Jaen", "Orense", "Baleares"
-#' )
+#' vals <- c("La Rioja", "Sevilla", "Madrid", "Jaen", "Orense", "Baleares")
+#'
 #' esp_dict_translate(vals)
 #' esp_dict_translate(vals, lang = "es")
 #' esp_dict_translate(vals, lang = "ca")
@@ -250,80 +220,72 @@ esp_dict_region_code <- function(sourcevar,
 #' esp_dict_translate(vals, lang = "ga")
 #'
 #' esp_dict_translate(vals, lang = "ga", all = TRUE)
-esp_dict_translate <-
-  function(sourcevar,
-           lang = "en",
-           all = FALSE) {
-    avlang <- c("es", "en", "ca", "ga", "eu")
-    if (!(lang %in% avlang)) {
-      stop("lang sould be one of ", paste0("'", avlang,
-        "'",
-        collapse = ", "
-      ))
-    }
-
-    # Create dict
-    dict <- names_full
-
-    # Arrange prelation for results:
-    # - First: prov (a_prov)
-    # - Second: ccaa (b_ccaa)
-    # - Last: nuts (c_nuts)
-    dict$variable <- gsub("prov", "a_prov", dict$variable) # Upgrade provs
-    dict$variable <- gsub("ccaa", "b_ccaa", dict$variable) # Upgrade nuts
-    dict$variable <- gsub("nuts", "c_nuts", dict$variable) # Upgrade nuts
-
-    names_dict <-
-      unique(names_full[grep("name", dict$variable), c("key", "value")])
-
-    tokeys <- countrycode::countrycode(
-      sourcevar,
-      origin = "value",
-      destination = "key",
-      custom_dict = names_dict,
-      nomatch = "NOMATCH"
+esp_dict_translate <- function(sourcevar, lang = "en", all = FALSE) {
+  avlang <- c("es", "en", "ca", "ga", "eu")
+  if (!(lang %in% avlang)) {
+    stop(
+      "lang sould be one of ",
+      paste0("'", avlang, "'", collapse = ", ")
     )
-
-    # Create lang dict
-    dict_tolang <-
-      unique(dict[grep(
-        paste0("name.", lang),
-        dict$variable
-      ), ])
-
-    # Order using short
-
-    shrt <- grep("short", dict_tolang$variable)
-
-    dict_tolang[shrt, ]$variable <-
-      paste0("aa", dict_tolang[shrt, ]$variable)
-
-    dict_tolang <-
-      unique(dict_tolang[order(dict_tolang$variable), c("key", "value")])
-
-
-    namestrans <-
-      lapply(seq(1, length(tokeys)), function(x) {
-        dict_tolang[dict_tolang$key == tokeys[x], "value"]
-      })
-
-    namestrans[tokeys == "NOMATCH"] <- NA
-
-    if (isTRUE(all)) {
-      names(namestrans) <- sourcevar
-    }
-
-    if (isFALSE(all)) {
-      namestrans <-
-        unlist(lapply(namestrans, `[[`, 1))
-    }
-
-    if (any(tokeys == "NOMATCH")) {
-      warning(
-        "No match found for ",
-        paste0(sourcevar[tokeys == "NOMATCH"], collapse = ", ")
-      )
-    }
-
-    return(namestrans)
   }
+
+  # Create dict
+  dict <- names_full
+
+  # Arrange prelation for results:
+  # - First: prov (a_prov)
+  # - Second: ccaa (b_ccaa)
+  # - Last: nuts (c_nuts)
+  dict$variable <- gsub("prov", "a_prov", dict$variable) # Upgrade provs
+  dict$variable <- gsub("ccaa", "b_ccaa", dict$variable) # Upgrade nuts
+  dict$variable <- gsub("nuts", "c_nuts", dict$variable) # Upgrade nuts
+
+  names_dict <- unique(
+    names_full[grep("name", dict$variable), c("key", "value")]
+  )
+
+  tokeys <- countrycode::countrycode(sourcevar,
+    origin = "value",
+    destination = "key",
+    custom_dict = names_dict,
+    nomatch = "NOMATCH"
+  )
+
+  # Create lang dict
+  dict_tolang <- unique(
+    dict[grep(paste0("name.", lang), dict$variable), ]
+  )
+
+  # Order using short
+  shrt <- grep("short", dict_tolang$variable)
+
+  dict_tolang[shrt, ]$variable <- paste0("aa", dict_tolang[shrt, ]$variable)
+
+  dict_tolang <- unique(
+    dict_tolang[order(dict_tolang$variable), c("key", "value")]
+  )
+
+
+  namestrans <- lapply(seq(1, length(tokeys)), function(x) {
+    dict_tolang[dict_tolang$key == tokeys[x], "value"]
+  })
+
+  namestrans[tokeys == "NOMATCH"] <- NA
+
+  if (isTRUE(all)) {
+    names(namestrans) <- sourcevar
+  }
+
+  if (isFALSE(all)) {
+    namestrans <- unlist(lapply(namestrans, `[[`, 1))
+  }
+
+  if (any(tokeys == "NOMATCH")) {
+    warning(
+      "No match found for ",
+      paste0(sourcevar[tokeys == "NOMATCH"], collapse = ", ")
+    )
+  }
+
+  return(namestrans)
+}
